pub fn format_time_wrt(t: SystemTime, now: SystemTime) -> FormattedTimeExpand description
Formats the given time in UTC using RFC3339 and, to aid interpretation, adds a human readable time delta.
Both time and time delta are rounded to seconds.
For example, at the time of writing the unix epoch is displayed thusly:
1970-01-01T00:00:00Z (2810w 13h 13m 23s ago)